from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, File, String

Hisat2_Align_L_V0_1_0 = CommandToolBuilder(tool="hisat2_align_l", base_command=["hisat2-align-l"], inputs=[ToolInput(tag="in_query_input_files_fastq", input_type=Boolean(optional=True), prefix="-q", doc=InputDocumentation(doc="query input files are FASTQ .fq/.fastq (default)")), ToolInput(tag="in_q_seq", input_type=Boolean(optional=True), prefix="--qseq", doc=InputDocumentation(doc="query input files are in Illumina's qseq format")), ToolInput(tag="in_query_input_files_multifasta", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="query input files are (multi-)FASTA .fa/.mfa")), ToolInput(tag="in_query_input_files_raw", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="query input files are raw one-sequence-per-line")), ToolInput(tag="in_m_m_r", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc="<m1>, <m2>, <r> are sequences themselves, not files")), ToolInput(tag="in_skip", input_type=Int(optional=True), prefix="--skip", doc=InputDocumentation(doc="skip the first <int> reads/pairs in the input (none)")), ToolInput(tag="in_up_to", input_type=Int(optional=True), prefix="--upto", doc=InputDocumentation(doc="stop after first <int> reads/pairs (no limit)")), ToolInput(tag="in_trim_five", input_type=Int(optional=True), prefix="--trim5", doc=InputDocumentation(doc="trim <int> bases from 5'/left end of reads (0)")), ToolInput(tag="in_trim_three", input_type=Int(optional=True), prefix="--trim3", doc=InputDocumentation(doc="trim <int> bases from 3'/right end of reads (0)")), ToolInput(tag="in_phred_three_three", input_type=Boolean(optional=True), prefix="--phred33", doc=InputDocumentation(doc="qualities are Phred+33 (default)")), ToolInput(tag="in_phred_six_four", input_type=Boolean(optional=True), prefix="--phred64", doc=InputDocumentation(doc="qualities are Phred+64")), ToolInput(tag="in_int_quals", input_type=Boolean(optional=True), prefix="--int-quals", doc=InputDocumentation(doc="qualities encoded as space-delimited integers")), ToolInput(tag="in_no_repeat_index", input_type=Int(optional=True), prefix="--no-repeat-index", doc=InputDocumentation(doc=",0,-0.5")), ToolInput(tag="in_n_ceil", input_type=Int(optional=True), prefix="--n-ceil", doc=InputDocumentation(doc="func for max # non-A/C/G/Ts permitted in aln (L,0,0.15)")), ToolInput(tag="in_ignore_quals", input_type=Boolean(optional=True), prefix="--ignore-quals", doc=InputDocumentation(doc="treat all quality values as 30 on Phred scale (off)")), ToolInput(tag="in_no_fw", input_type=Boolean(optional=True), prefix="--nofw", doc=InputDocumentation(doc="do not align forward (original) version of read (off)")), ToolInput(tag="in_norc", input_type=Boolean(optional=True), prefix="--norc", doc=InputDocumentation(doc="do not align reverse-complement version of read (off)")), ToolInput(tag="in_pen_can_splice", input_type=Int(optional=True), prefix="--pen-cansplice", doc=InputDocumentation(doc="penalty for a canonical splice site (0)")), ToolInput(tag="in_pen_non_can_splice", input_type=Int(optional=True), prefix="--pen-noncansplice", doc=InputDocumentation(doc="penalty for a non-canonical splice site (12)")), ToolInput(tag="in_pen_can_intron_len", input_type=Int(optional=True), prefix="--pen-canintronlen", doc=InputDocumentation(doc="penalty for long introns (G,-8,1) with canonical splice sites")), ToolInput(tag="in_pen_non_can_intron_len", input_type=Int(optional=True), prefix="--pen-noncanintronlen", doc=InputDocumentation(doc="penalty for long introns (G,-8,1) with noncanonical splice sites")), ToolInput(tag="in_min_intron_len", input_type=Int(optional=True), prefix="--min-intronlen", doc=InputDocumentation(doc="minimum intron length (20)")), ToolInput(tag="in_max_intron_len", input_type=Int(optional=True), prefix="--max-intronlen", doc=InputDocumentation(doc="maximum intron length (500000)")), ToolInput(tag="in_known_splice_site_in_file", input_type=File(optional=True), prefix="--known-splicesite-infile", doc=InputDocumentation(doc="provide a list of known splice sites")), ToolInput(tag="in_novel_splice_site_outfile", input_type=File(optional=True), prefix="--novel-splicesite-outfile", doc=InputDocumentation(doc="report a list of splice sites")), ToolInput(tag="in_novel_splice_site_in_file", input_type=File(optional=True), prefix="--novel-splicesite-infile", doc=InputDocumentation(doc="provide a list of novel splice sites")), ToolInput(tag="in_no_temp_splice_site", input_type=Boolean(optional=True), prefix="--no-temp-splicesite", doc=InputDocumentation(doc="disable the use of splice sites found")), ToolInput(tag="in_no_spliced_alignment", input_type=Boolean(optional=True), prefix="--no-spliced-alignment", doc=InputDocumentation(doc="disable spliced alignment")), ToolInput(tag="in_rna_strand_ness", input_type=String(optional=True), prefix="--rna-strandness", doc=InputDocumentation(doc="specify strand-specific information (unstranded)")), ToolInput(tag="in_tmo", input_type=Boolean(optional=True), prefix="--tmo", doc=InputDocumentation(doc="reports only those alignments within known transcriptome")), ToolInput(tag="in_dta", input_type=Boolean(optional=True), prefix="--dta", doc=InputDocumentation(doc="reports alignments tailored for transcript assemblers")), ToolInput(tag="in_dta_cufflinks", input_type=Boolean(optional=True), prefix="--dta-cufflinks", doc=InputDocumentation(doc="reports alignments tailored specifically for cufflinks")), ToolInput(tag="in_avoid_pseudogene", input_type=Boolean(optional=True), prefix="--avoid-pseudogene", doc=InputDocumentation(doc="tries to avoid aligning reads to pseudogenes (experimental option)")), ToolInput(tag="in_no_template_len_adjustment", input_type=Boolean(optional=True), prefix="--no-templatelen-adjustment", doc=InputDocumentation(doc="disables template length adjustment for RNA-seq reads")), ToolInput(tag="in_mp", input_type=Int(optional=True), prefix="--mp", doc=InputDocumentation(doc=",<int>   max and min penalties for mismatch; lower qual = lower penalty <6,2>")), ToolInput(tag="in_sp", input_type=Int(optional=True), prefix="--sp", doc=InputDocumentation(doc=",<int>   max and min penalties for soft-clipping; lower qual = lower penalty <2,1>")), ToolInput(tag="in_no_soft_clip", input_type=Boolean(optional=True), prefix="--no-softclip", doc=InputDocumentation(doc="no soft-clipping")), ToolInput(tag="in_np", input_type=Int(optional=True), prefix="--np", doc=InputDocumentation(doc="penalty for non-A/C/G/Ts in read/ref (1)")), ToolInput(tag="in_rdg", input_type=Int(optional=True), prefix="--rdg", doc=InputDocumentation(doc=",<int>  read gap open, extend penalties (5,3)")), ToolInput(tag="in_rfg", input_type=Int(optional=True), prefix="--rfg", doc=InputDocumentation(doc=",<int>  reference gap open, extend penalties (5,3)")), ToolInput(tag="in_max_seeds", input_type=Int(optional=True), prefix="--max-seeds", doc=InputDocumentation(doc="HISAT2, like other aligners, uses seed-and-extend approaches. HISAT2 tries to extend seeds to\nfull-length alignments. In HISAT2, --max-seeds is used to control the maximum number of seeds that\nwill be extended. For DNA-read alignment (--no-spliced-alignment), HISAT2 extends up to these many seeds\nand skips the rest of the seeds. For RNA-read alignment, HISAT2 skips extending seeds and reports\nno alignments if the number of seeds is larger than the number specified with the option,\nto be compatible with previous versions of HISAT2. Large values for --max-seeds may improve alignment\nsensitivity, but HISAT2 is not designed with large values for --max-seeds in mind, and when aligning\nreads to long, repetitive genomes, large --max-seeds could make alignment much slower.\nThe default value is the maximum of 5 and the value that comes with -k times 2.")), ToolInput(tag="in_all", input_type=Boolean(optional=True), prefix="--all", doc=InputDocumentation(doc="HISAT2 reports all alignments it can find. Using the option is equivalent to using both --max-seeds\nand -k with the maximum value that a 64-bit signed integer can represent (9,223,372,036,854,775,807).")), ToolInput(tag="in_repeat", input_type=Boolean(optional=True), prefix="--repeat", doc=InputDocumentation(doc="report alignments to repeat sequences directly")), ToolInput(tag="in_mini_ns", input_type=Int(optional=True), prefix="--minins", doc=InputDocumentation(doc="minimum fragment length (0), only valid with --no-spliced-alignment")), ToolInput(tag="in_max_ins", input_type=Int(optional=True), prefix="--maxins", doc=InputDocumentation(doc="maximum fragment length (500), only valid with --no-spliced-alignment")), ToolInput(tag="in_fr", input_type=String(optional=True), prefix="--fr", doc=InputDocumentation(doc="align fw/rev, rev/fw, fw/fw (--fr)")), ToolInput(tag="in_no_mixed", input_type=Boolean(optional=True), prefix="--no-mixed", doc=InputDocumentation(doc="suppress unpaired alignments for paired reads")), ToolInput(tag="in_no_discordant", input_type=Boolean(optional=True), prefix="--no-discordant", doc=InputDocumentation(doc="suppress discordant alignments for paired reads")), ToolInput(tag="in_time", input_type=Boolean(optional=True), prefix="--time", doc=InputDocumentation(doc="print wall-clock time taken by search phases")), ToolInput(tag="in_summary_file", input_type=File(optional=True), prefix="--summary-file", doc=InputDocumentation(doc="print alignment summary to this file.")), ToolInput(tag="in_new_summary", input_type=Boolean(optional=True), prefix="--new-summary", doc=InputDocumentation(doc="print alignment summary in a new style, which is more machine-friendly.")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="print nothing to stderr except serious errors")), ToolInput(tag="in_met_file", input_type=File(optional=True), prefix="--met-file", doc=InputDocumentation(doc="send metrics to file at <path> (off)")), ToolInput(tag="in_met_stderr", input_type=Boolean(optional=True), prefix="--met-stderr", doc=InputDocumentation(doc="send metrics to stderr (off)")), ToolInput(tag="in_met", input_type=Int(optional=True), prefix="--met", doc=InputDocumentation(doc="report internal counters & metrics every <int> secs (1)")), ToolInput(tag="in_no_head", input_type=Boolean(optional=True), prefix="--no-head", doc=InputDocumentation(doc="suppress header lines, i.e. lines starting with @")), ToolInput(tag="in_no_sq", input_type=Boolean(optional=True), prefix="--no-sq", doc=InputDocumentation(doc="suppress @SQ header lines")), ToolInput(tag="in_rg_id", input_type=String(optional=True), prefix="--rg-id", doc=InputDocumentation(doc="set read group id, reflected in @RG line and RG:Z: opt field")), ToolInput(tag="in_rg", input_type=String(optional=True), prefix="--rg", doc=InputDocumentation(doc="add <text> ('lab:value') to @RG line of SAM header.\nNote: @RG line only printed when --rg-id is set.")), ToolInput(tag="in_omit_sec_seq", input_type=Boolean(optional=True), prefix="--omit-sec-seq", doc=InputDocumentation(doc="put '*' in SEQ and QUAL fields for secondary alignments.")), ToolInput(tag="in_off_rate", input_type=Int(optional=True), prefix="--offrate", doc=InputDocumentation(doc="override offrate of index; must be >= index's offrate")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="number of alignment threads to launch (1)")), ToolInput(tag="in_reorder", input_type=Boolean(optional=True), prefix="--reorder", doc=InputDocumentation(doc="force SAM output order to match order of input reads")), ToolInput(tag="in_mm", input_type=Boolean(optional=True), prefix="--mm", doc=InputDocumentation(doc="use memory-mapped I/O for index; many 'hisat2's can share")), ToolInput(tag="in_qc_filter", input_type=Boolean(optional=True), prefix="--qc-filter", doc=InputDocumentation(doc="filter out reads that are bad according to QSEQ filter")), ToolInput(tag="in_seed", input_type=Int(optional=True), prefix="--seed", doc=InputDocumentation(doc="seed for random number generator (0)")), ToolInput(tag="in_non_deterministic", input_type=String(optional=True), prefix="--non-deterministic", doc=InputDocumentation(doc="rand. gen. arbitrarily instead of using read attributes")), ToolInput(tag="in_remove_chr_name", input_type=Boolean(optional=True), prefix="--remove-chrname", doc=InputDocumentation(doc="remove 'chr' from reference names in alignment")), ToolInput(tag="in_add_chr_name", input_type=Boolean(optional=True), prefix="--add-chrname", doc=InputDocumentation(doc="add 'chr' to reference names in alignment")), ToolInput(tag="in_his_at_two_align", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_ht_two_idx", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_m_one", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_m_two", input_type=Int(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_73", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_74", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_specified", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_file", input_type=File(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_files", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_index", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_many", input_type=String(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_filename", input_type=File(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_for", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_times_dot", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_with", input_type=String(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_e_dot_gdot", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_var_85", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_prefix", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_unpaired", input_type=String(), position=3, doc=InputDocumentation(doc="")), ToolInput(tag="in_output", input_type=String(), position=4, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Hisat2_Align_L_V0_1_0().translate("wdl", allow_empty_container=True)

